# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u1A15',
            '\u1A15\u02BD',
            '\u1A15\u1A17',
            '\u1A15\u1A17\u02BD',
            '\u1A15\u1A18',
            '\u1A15\u1A18\u02BD',
            '\u1A11\u1A18\u02BD',
            '\u1A11\u1A18\u02BD',
            '\u1A12\u1A18\u02BD',
            '\u1A12\u1A18\u02BD',
            '\u1A15\u1A19\u02BD',
            '\u1A15\u1A15\u1A17\u02BD',
            '\u1A15\u1A1A\u02BD',
            '\u1A15\u1A15\u1A18\u02BD',
            ]

SouthVowelMap = [
                '\u1A15\u1A19',
                '\u1A15\u1A1A',
                ]

ModernVowelMap = [
                 '\u1A15\u1A1B',
                 '\u1A15\u02BD',
                 ]

SinhalaVowelMap = [
                  '\u1A15\u1A1B\u02BD'
                  ]

VowelSignMap =  [
                '\u02BD\u02BD',
                '\u1A17',
                '\u1A17\u02BD',
                '\u1A18',
                '\u1A18\u02BD',
                '\u1A11\u1A18\u02BD',
                '\u1A11\u1A18\u02BD',
                '\u1A12\u1A18\u02BD',
                '\u1A12\u1A18\u02BD',
                '\u1A19\u02BD',
                '\u1A15\u1A17\u02BD',
                '\u1A1A\u02BD',
                '\u1A15\u1A18\u02BD',
                ]

SouthVowelSignMap = [
                     '\u1A19',
                     '\u1A1A',
                    ]

ModernVowelSignMap =[
                     '\u1A1B',
                     '\u02BD\u02BD\u02BD',
                    ]

SinhalaVowelSignMap = [
                      '\u1A1B\u02BD'
                      ]

AyogavahaMap = [
               '\u1A06\u02BD',
               '\u1A06\u02BD',
               '\u1A16\u02BD'
               ]

ViramaMap =  [
             '\u02BE'
             ]

ConsonantMap =  [
                '\u1A00',
                '\u1A00\u02BD',
                '\u1A01',
                '\u1A01\u02BD',
                '\u1A02',

                '\u1A0C',
                '\u1A0C\u02BD',
                '\u1A0D',
                '\u1A0D\u02BD',
                '\u1A0E',

                '\u1A08\u02BD',
                '\u1A08\u02BD',
                '\u1A09\u02BD',
                '\u1A09\u02BD',
                '\u1A0A\u02BD',

                '\u1A08',
                '\u1A08\u02BD',
                '\u1A09',
                '\u1A09\u02BD',
                '\u1A0A',

                '\u1A04',
                '\u1A04\u02BD',
                '\u1A05',
                '\u1A05\u02BD',
                '\u1A06',

                '\u1A10',
                '\u1A11',
                '\u1A12',
                '\u1A13',

                '\u1A14\u02BD',
                '\u1A14\u02BD',
                '\u1A14',
                '\u1A16'
                ]

SouthConsonantMap = [
                    '\u1A12\u02BD',
                    '\u1A12\u02BD',
                    '\u1A11\u02BD',
                    '\u1A0A\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\u1A00\u02BD',
                     '\u1A00\u02BD',
                     '\u1A01\u02BD',
                     '\u1A0D\u02BD',
                     '\u1A09\u02BD',
                     '\u1A09\u02BD',
                     '\u1A04\u02BD',
                     '\u1A10\u02BD'
                     ]
SinhalaConsonantMap =[
                     '\u1A02\u1A01\u02BD',
                     '\u1A0E\u1A0D\u02BD',
                     '\u1A0A\u1A09\u02BD',
                     '\u1A0A\u1A09\u02BD',
                     '\u1A06\u1A05\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        '\u1A15\u1A1A\u1A06\u02BD'
        ]

SignMap =[
         "\u02BD\u02BD",
         '᨞',
         '᨞᨞'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']

NumeralMap = [
             '\u0030',
             '\u0031',
             '\u0032',
             '\u0033',
             '\u0034',
             '\u0035',
             '\u0036',
             '\u0037',
             '\u0038',
             '\u0039',
             ]
